Pyramid Social Network Authentication
=====================================

.. image:: https://secure.travis-ci.org/lorenzogil/pyramid_sna.png

pyramid_sna is a Pyramid library for authenticating users using OAuth2
providers.

It is released under the terms of a 3 clause BSD license and it is
based on code originally from the
`Yith Library Server <https://github.com/Yaco-Sistemas/yith-library-server>`_
project.

You can learn how to use it reading the documentation in the *docs* directory.
